// SPDX-FileCopyrightText: 2024 The Phosh Developers
// SPDX-License-Identifier: GPL-3.0-or-later

baseURLs = [
  [ 'GLib', 'https://docs.gtk.org/glib/' ],
  [ 'GObject', 'https://docs.gtk.org/gobject/' ],
  [ 'Gio', 'https://docs.gtk.org/gio/' ],
  [ 'Gtk', 'https://docs.gtk.org/gtk3/' ]
]
