/*
 * Copyright (C) 2022 The Phosh Developers
 *
 * SPDX-License-Identifier: LGPL-2.1-or-later
 *
 * Author: Guido Günther <agx@sigxcpu.org>
 */

#include "gm-error.h"

/**
 * gm_error_quark:
 *
 * Gets the GM Error Quark.
 *
 * Returns: a #GQuark.
 *
 * Since: 0.0.1
 **/
G_DEFINE_QUARK (gm-error-quark, gm_error)
